@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calcoptions.h
- * Version    : $Id: ipv6calcoptions.h,v 1.9 2006/06/07 13:18:28 peter Exp $
+ * Version    : $Id: ipv6calcoptions.h,v 1.10 2006/08/06 12:44:14 peter Exp $
  * Copyright  : 2002-2006 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -33,15 +33,17 @@
  *  m = output machine readable
  *  i = showinfo
  *  q = be more quiet
- *  p <path to ip2location file> = path to IP2Location file
+ *  p <path to IP2Location file> = path to IP2Location database file
+ *  g <path to GeoIP file> = path to GeoIP database file
  */
-/*@unused@*/ static char *ipv6calc_shortopts = "vh?p:rmabd:iulqUFCI:O:A:";
+/*@unused@*/ static char *ipv6calc_shortopts = "vh?p:g:rmabd:iulqUFCI:O:A:";
 
 /* define long options */
 /*@unused@*/ static struct option ipv6calc_longopts[] = {
 	{"version", 0, 0, (int) 'v'},
 	{"debug", 1, 0, (int) 'd'},
 	{"path", 1, 0, (int) 'p'},
+	{"path-geoip", 1, 0, (int) 'g'},
 
 	/* help options */
 	{"help", 0, 0, (int) 'h'},
