@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6addr.c
- * Version    : $Id: libipv6addr.c,v 1.25 2005/10/26 09:36:54 peter Exp $
- * Copyright  : 2001-2005 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
+ * Version    : $Id: libipv6addr.c,v 1.28 2006/06/12 19:55:18 peter Exp $
+ * Copyright  : 2001-2006 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
  *  Function library for IPv6 address handling
@@ -300,8 +300,9 @@ uint32_t ipv6addr_gettype(const ipv6calc_ipv6addr *ipv6addrp) {
 		};
 	};
 
-	if (st == 0x3FFE831Fu) {
-		/* 3ffe:831f::/32 -> Teredo */
+	if (st == 0x3FFE831Fu || st == 0x20010000u) {
+		/* 3ffe:831f::/32 -> Teredo (6bone, older draft) */
+		/* 2001:0000::/32 -> Teredo (RFC 4380) */
 		type |= IPV6_NEW_ADDR_TEREDO;
 	};
 	
@@ -311,13 +312,14 @@ uint32_t ipv6addr_gettype(const ipv6calc_ipv6addr *ipv6addrp) {
 		type |= IPV6_NEW_ADDR_PRODUCTIVE;
 	};
 	
-	if ((st2 == (uint32_t) 0x00000001u) && (st3 & 0xFF000000u) == 0xFF000000u) {
+	if ((st2 == 0x00000001u) && (st3 & 0xFF000000u) == 0xFF000000u) {
 		/* ..:0000:0001:ffxx:xxxx solicited node suffix */
 		type |= IPV6_NEW_ADDR_SOLICITED_NODE;
 	};
 
-	if (st2 == (uint32_t) 0x00005EFEu) {
-		/* ..:0000:5EFE:xx.xx.xx.xx ISATAP suffix */
+	if (st2 == 0x00005EFEu && ((type & IPV6_NEW_ADDR_TEREDO) == 0)) {
+		/* ..:0000:5EFE:xx.xx.xx.xx ISATAP suffix (RFC 4214) */
+		/* but not if TEREDO */
 		type |= IPV6_NEW_ADDR_ISATAP;
 	};
 
