@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : librfc3041.c
- * Version    : $Id: librfc3041.c,v 1.5 2002/04/20 14:27:55 peter Exp $
- * Copyright  : 2001-2002 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: librfc3041.c,v 1.9 2005/09/15 12:14:00 peter Exp $
+ * Copyright  : 2001-2004 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Function libary for host identifier privacy extension defined in RFC 3041
@@ -16,7 +16,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include <openssl/md5.h>
+#include "../md5/md5.h"
 #include "libipv6calc.h"
 #include "libipv6calcdebug.h"
 #include "librfc3041.h"
@@ -33,7 +33,7 @@
 int librfc3041_calc(ipv6calc_ipv6addr *identifier, ipv6calc_ipv6addr *token, ipv6calc_ipv6addr *newidentifier, ipv6calc_ipv6addr *newtoken) {
 #define DEBUG_function_name "librfc3041/librfc3041_calc"
 	int retval = 1, i;
-	MD5_CTX md5hash;
+	struct md5_ctx md5hash;
 	char tempstring[NI_MAXHOST],  tempstring2[NI_MAXHOST];
 	unsigned char digest[MD5_DIGEST_LENGTH];
 
@@ -41,18 +41,18 @@ int librfc3041_calc(ipv6calc_ipv6addr *identifier, ipv6calc_ipv6addr *token, ipv
 		fprintf(stderr, "%s: Got identifier '%08x-%08x' and token '%08x-%08x'\n", DEBUG_function_name, (unsigned int) ipv6addr_getdword(identifier, 2), (unsigned int) ipv6addr_getdword(identifier, 3), (unsigned int) ipv6addr_getdword(token, 2), (unsigned int) ipv6addr_getdword(token, 3)); 
 	};
 
-	MD5_Init(&md5hash);
+	md5_init_ctx(&md5hash);
 
-	MD5_Update(&md5hash, &identifier->in6_addr.s6_addr[8], 8);
-	MD5_Update(&md5hash, &token->in6_addr.s6_addr[8], 8);
+	md5_process_bytes(&identifier->in6_addr.s6_addr[8], 8, &md5hash);
+	md5_process_bytes(&token->in6_addr.s6_addr[8], 8, &md5hash);
 
-	MD5_Final(digest, &md5hash);
+	md5_finish_ctx(&md5hash, digest);
 
 	tempstring[0] = '\0';
 
 	for (i = 0; i < MD5_DIGEST_LENGTH; i++) {
-		snprintf(tempstring2, sizeof(tempstring2), "%s%02x", tempstring, digest[i]);
-		snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
+		snprintf(tempstring2, sizeof(tempstring2) - 1, "%s%02x", tempstring, (int) digest[i]);
+		snprintf(tempstring, sizeof(tempstring) - 1, "%s", tempstring2);
 	};
 	
 	if ( (ipv6calc_debug & DEBUG_librfc3041) != 0 ) {
